ExpirationEnforcement

Enum ExpirationEnforcement 

pub enum ExpirationEnforcement {
    Safe,
    Unsafe,
}
Represents whether a Repository should fail to load when metadata is expired (Safe) or whether it should ignore expired metadata (Unsafe). Only use Unsafe if you are sure you need it.

Variants



Safe

Expirations will be enforced. You MUST use this option to get TUF security guarantees.



Unsafe

Expirations will not be enforced. This is available for certain offline use cases, does NOT provide TUF security guarantees, and should only be used if you are sure that you need it.