Encode

Trait Encode 

pub trait Encode {
    // Required method
    fn encode(b: &[u8]) -> String;
}
A trait that represents how data can be converted from bytes to a string.

Generally structs that implement Decode will be unit-like structs that just implement the one required method.

Required Methods

fn encode(b: &[u8]) -> String

Convert bytes to a string. This method cannot fail.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors